@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "project-tasks" "0.7.1"
+(define-package "project-tasks" "20241220.1028"
   "Efficient task management for your project."
   '((emacs   "26.1")
     (project "0.6.0"))
